@@ -15,14 +15,9 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginLoader>
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
 #include <KPluginMetaData>
 #include <KAboutPluginDialog>
-#else
-#include <KAboutApplicationDialog>
-#endif
 #include <KMessageBox>
-
 // Qt
 #include <QAction>
 #include <QApplication>
@@ -69,11 +64,7 @@ KPartLoaderWindow::~KPartLoaderWindow()
 
 void KPartLoaderWindow::aboutKPart()
 {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     KAboutPluginDialog dlg(m_part->metaData(), this);
-#else
-    KAboutApplicationDialog dlg(m_part->componentData(), this);
-#endif
     dlg.exec();
 }
 
